



#include "../plugin/rsacard_p.h"
#include <aqhbci/hbci.h>
#include <gwenhywfar/logger.h>
#include <gwenhywfar/debug.h>
#include <aqbanking/banking_be.h>


int main(int argc, char **argv) {
  AH_MEDIUM *m;
  AH_HBCI *hbci;
  AB_BANKING *ab;
  AB_PROVIDER *provider;
  int rv;
  GWEN_DB_NODE *dbData;

  GWEN_Logger_SetLevel(0, GWEN_LoggerLevelInfo);

  ab=AB_Banking_new("rsacardtest", 0);
  rv=AB_Banking_Init(ab);
  if (rv) {
    DBG_ERROR(0, "Error on init (%d)", rv);
    AB_Banking_free(ab);
    return 2;
  }
  provider=AB_Banking_GetProvider(ab, "aqhbci");
  hbci=AH_HBCI_new(provider);
  m=AH_HBCI_SelectMedium(hbci, AH_MEDIUM_RSACARD_NAME, 0);
  if (!m) {
    DBG_ERROR(0, "Could not select medium.");
    AB_Banking_Fini(ab);
    AB_Banking_free(ab);
    return 2;
  }

  DBG_NOTICE(0, "Mounting medium");
  rv=AH_Medium_Mount(m);
  if (rv) {
    DBG_ERROR(0, "Error on mount (%d)", rv);
    AB_Banking_Fini(ab);
    AB_Banking_free(ab);
    return 2;
  }
  DBG_NOTICE(0, "Mounted medium");

  dbData=GWEN_DB_Group_new("data");
  rv=AH_Medium_ToDB(m, dbData);
  if (rv) {
    DBG_ERROR(0, "Error on toDB (%d)", rv);
    AB_Banking_Fini(ab);
    AB_Banking_free(ab);
    return 2;
  }

  if (GWEN_DB_WriteFile(dbData,
			"medium.conf",
			GWEN_DB_FLAGS_DEFAULT)) {
    DBG_ERROR(0, "Error writing medium.conf");
    AH_Medium_Unmount(m, 1);
    AB_Banking_Fini(ab);
    AB_Banking_free(ab);
    return 2;
  }
  GWEN_DB_Dump(dbData, stderr, 2);

  DBG_NOTICE(0, "Unmounting medium");
  rv=AH_Medium_Unmount(m, 1);
  if (rv) {
    DBG_ERROR(0, "Error on unmount (%d)", rv);
    AB_Banking_Fini(ab);
    AB_Banking_free(ab);
    return 2;
  }
  DBG_NOTICE(0, "Unmounted medium");

  AB_Banking_Fini(ab);
  AB_Banking_free(ab);
  return 0;
}

